# broccoli

Some useful PyTorch models, circa 2025.

![broccoli](broccoli.png "Image of a rockstar made of broccoli")

# Getting started

You can install broccoli with

```
pip install broccoli-ml
```

PyTorch is a peer dependency of `broccoli`, which means
  * You will need to make sure you have PyTorch installed in order to use `broccoli`
  * PyTorch will **not** be installed automatically when you install `broccoli`

We take this approach because PyTorch versioning is environment-specific and we don't know where you will want to use `broccoli`. If we automatically install PyTorch for you, there's a good chance we would get it wrong!

Therefore, please also make sure you install PyTorch.

# Usage examples

...